@@ -27,7 +27,7 @@ class CTProductsViewResourceSchema(Schema):
     updated_at = fields.DateTime(dump_only=True)
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['news_date', 'study_start_date']
 
         in_data = pre_load_date_fields(
