@@ -15,6 +15,8 @@ class CrawlerLogResourceSchema(Schema):
     company_sec_id = fields.Integer(allow_none=True)
     company_ous_id = fields.Integer(allow_none=True)
     crawl_time = fields.Float(required=True)
+    base_crawl_time = fields.Float(allow_none=True)
+    base_crawl_completed = fields.Boolean(allow_none=True)
     crawl_date = fields.DateTime(required=True)
     updated_at = fields.DateTime()
 
