@@ -12,7 +12,7 @@ class DocTextResourceSchema(Schema):
     news_id = fields.Integer(allow_none=True)
     sec_filing_id = fields.Integer(allow_none=True)
     company_filing_id = fields.Integer(allow_none=True)
-    company_scientific_link_id = fields.Integer(allow_none=True)
+    scientific_link_id = fields.Integer(allow_none=True)
     pubmed_id = fields.Integer(allow_none=True)
     text_type = fields.String(allow_none=True)
     text = fields.String(required=True)
