@@ -30,8 +30,9 @@ class NCTStudyModel(Base):
     study_start_date = Column(DateTime)
     last_update_submitted_qc_date = Column(DateTime)
     phase = Column(Text)
-    sponsors = Column(Text)
-    conditions = Column(Text)
+    sponsors = Column(Text, nullable=True)
+    conditions = Column(Text, nullable=True)
+    interventions = Column(Text, nullable=True)
     industry_flag = Column(Boolean)
     updated_at = Column(
         DateTime,
