@@ -6,6 +6,7 @@ from sqlalchemy import (
     DateTime,
     UniqueConstraint,
     ForeignKey,
+    Boolean,
 )
 
 from ...database import Base
@@ -25,6 +26,7 @@ class PubmedPublicationTypeMapModel(Base):
         ForeignKey('pubmed_publication_types.id'),
         nullable=False,
     )
+    processed = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
