@@ -14,7 +14,7 @@ class RelatedMatterResourceSchema(Schema):
     updated_at = fields.DateTime(dump_only=True)
 
     @pre_load
-    def pre_load(self, in_data, **kwargs):
+    def check_pacer_ids(self, in_data, **kwargs):
         if ('related_pacer_case_id' in in_data and
                 'related_ptab2_proceeding_id' in in_data):
             raise ValidationError(
@@ -27,6 +27,8 @@ class RelatedMatterResourceSchema(Schema):
                 'Should provide either `related_pacer_case_id` or '
                 '`related_ptab2_proceeding_id` field')
 
+        return in_data
+
 
 class RelatedMatterQueryParamsSchema(Schema):
     id = fields.Integer()
